==> h2o_engine_manager-0.3.2.tar.gz: h2o_engine_manager-0.3.2/tests/integration/api/h2o/test_list_h2o_engines.py <==
import time
from typing import List

from h2o_engine_manager.clients.h2o_engine.h2o_engine import H2OEngine
from tests.integration.conftest import CACHE_SYNC_SECONDS


def create_engines(h2o_engine_client, workspace_id):
    h2o_engine_client.create_engine(
        workspace_id=workspace_id,
        engine_id="e1",
        version="3.38.0.2",
        cpu=1,
        gpu=0,
        memory_bytes="2Gi",
        display_name="my engine 1",
        max_idle_duration="5h",
        max_running_duration="10h",
    )

    h2o_engine_client.create_engine(
        workspace_id=workspace_id,
        engine_id="e2",
        version="3.36.1.5",
        cpu=2,
        gpu=0,
        memory_bytes="2Gi",
        display_name="my engine 2",
        max_idle_duration="5h",
        max_running_duration="10h",
    )

    h2o_engine_client.create_engine(
        workspace_id=workspace_id,
        engine_id="e3",
        version="3.38.0.1",
        cpu=3,
        gpu=0,
        memory_bytes="2Gi",
        display_name="my engine 3",
        max_idle_duration="5h",
        max_running_duration="10h",
    )

    time.sleep(CACHE_SYNC_SECONDS)


def test_list(h2o_engine_client):
    workspace_id = "list-h2o-engines"

    # No engines to be found.
    page = h2o_engine_client.list_engines(workspace_id=workspace_id)
    assert len(page.engines) == 0
    assert page.next_page_token == ""
    assert page.total_size == 0

    create_engines(h2o_engine_client=h2o_engine_client, workspace_id=workspace_id)

    # List first page.
    page = h2o_engine_client.list_engines(workspace_id=workspace_id, page_size=1)
    assert len(page.engines) == 1
    assert page.next_page_token != ""
    assert page.total_size == 3

    # List second (last) page.
    page = h2o_engine_client.list_engines(
        workspace_id=workspace_id, page_size=2, page_token=page.next_page_token
    )
    assert len(page.engines) == 2
    assert page.next_page_token == ""
    assert page.total_size == 3

    # Test exceeding max page size.
    page = h2o_engine_client.list_engines(workspace_id=workspace_id, page_size=1001)
    assert len(page.engines) == 3
    assert page.next_page_token == ""
    assert page.total_size == 3

    # Test empty after filter.
    page = h2o_engine_client.list_engines(
        workspace_id=workspace_id, filter="cpu = 0 AND cpu != 0"
    )
    assert len(page.engines) == 0
    assert page.next_page_token == ""
    assert page.total_size == 0

    # Test orderBy and filter.
    page = h2o_engine_client.list_engines(
        workspace_id=workspace_id,
        order_by="cpu asc, name desc",
        filter="cpu >= 2 AND gpu <= 2",
    )
    assert len(page.engines) == 2
    assert page.next_page_token == ""
    assert page.total_size == 2
    check_ordered_filtered(engines=page.engines)

    # List all with order and filter (+ testing version alias filtering).
    engines = h2o_engine_client.list_all_engines(
        workspace_id=workspace_id, order_by="version desc", filter="version < latest"
    )
    assert len(engines) == 2
    assert engines[0].version == "3.38.0.1"
    assert engines[1].version == "3.36.1.5"


def check_ordered_filtered(engines: List[H2OEngine]):
    # Hardcoded values based on filter/orderBy params in tests.
    for i in range(0, len(engines) - 1):
        assert engines[i].cpu >= 2
        assert engines[i].gpu <= 2

        assert engines[i].cpu <= engines[i + 1].cpu
        if engines[i].cpu == engines[i + 1].cpu:
            assert engines[i].name >= engines[i + 1].name

==> h2o_engine_manager-0.8.0.tar.gz: h2o_engine_manager-0.8.0/tests/integration/api/h2o/test_list_h2o_engines.py <==
import time
from typing import List

from h2o_engine_manager.clients.h2o_engine.h2o_engine import H2OEngine
from tests.integration.conftest import CACHE_SYNC_SECONDS


def create_engines(h2o_engine_client, workspace_id):
    h2o_engine_client.create_engine(
        workspace_id=workspace_id,
        engine_id="e1",
        version="3.40.0.3",
        node_count=1,
        cpu=1,
        gpu=0,
        memory_bytes="2Gi",
        display_name="my engine 1",
        max_idle_duration="5h",
        max_running_duration="10h",
    )

    h2o_engine_client.create_engine(
        workspace_id=workspace_id,
        engine_id="e2",
        version="3.36.1.5",
        node_count=1,
        cpu=2,
        gpu=0,
        memory_bytes="2Gi",
        display_name="my engine 2",
        max_idle_duration="5h",
        max_running_duration="10h",
    )

    h2o_engine_client.create_engine(
        workspace_id=workspace_id,
        engine_id="e3",
        version="3.38.0.4",
        node_count=1,
        cpu=3,
        gpu=0,
        memory_bytes="2Gi",
        display_name="my engine 3",
        max_idle_duration="5h",
        max_running_duration="10h",
    )

    time.sleep(CACHE_SYNC_SECONDS)


def test_list(h2o_engine_client):
    workspace_id = "list-h2o-engines"

    # No engines to be found.
    page = h2o_engine_client.list_engines(workspace_id=workspace_id)
    assert len(page.engines) == 0
    assert page.next_page_token == ""
    assert page.total_size == 0

    create_engines(h2o_engine_client=h2o_engine_client, workspace_id=workspace_id)

    # List first page.
    page = h2o_engine_client.list_engines(workspace_id=workspace_id, page_size=1)
    assert len(page.engines) == 1
    assert page.next_page_token != ""
    assert page.total_size == 3

    # List second (last) page.
    page = h2o_engine_client.list_engines(
        workspace_id=workspace_id, page_size=2, page_token=page.next_page_token
    )
    assert len(page.engines) == 2
    assert page.next_page_token == ""
    assert page.total_size == 3

    # Test exceeding max page size.
    page = h2o_engine_client.list_engines(workspace_id=workspace_id, page_size=1001)
    assert len(page.engines) == 3
    assert page.next_page_token == ""
    assert page.total_size == 3

    # Test empty after filter.
    page = h2o_engine_client.list_engines(
        workspace_id=workspace_id, filter="cpu = 0 AND cpu != 0"
    )
    assert len(page.engines) == 0
    assert page.next_page_token == ""
    assert page.total_size == 0

    # Test orderBy and filter.
    page = h2o_engine_client.list_engines(
        workspace_id=workspace_id,
        order_by="cpu asc, name desc",
        filter="cpu >= 2 AND gpu <= 2",
    )
    assert len(page.engines) == 2
    assert page.next_page_token == ""
    assert page.total_size == 2
    check_ordered_filtered(engines=page.engines)

    # List all with order and filter (+ testing version alias filtering).
    engines = h2o_engine_client.list_all_engines(
        workspace_id=workspace_id, order_by="version desc", filter="version < \"smoker\""
    )
    assert len(engines) == 2
    assert engines[0].version == "3.38.0.4"
    assert engines[1].version == "3.36.1.5"


def check_ordered_filtered(engines: List[H2OEngine]):
    # Hardcoded values based on filter/orderBy params in tests.
    for i in range(0, len(engines) - 1):
        assert engines[i].cpu >= 2
        assert engines[i].gpu <= 2

        assert engines[i].cpu <= engines[i + 1].cpu
        if engines[i].cpu == engines[i + 1].cpu:
            assert engines[i].name >= engines[i + 1].name
